<template>
  <div class="p-2">
    <transition :enter-active-class="proxy?.animate.searchAnimate.enter" :leave-active-class="proxy?.animate.searchAnimate.leave">
      <div v-show="showSearch" class="mb-[10px]">
        <el-card shadow="hover">
          <el-form ref="queryFormRef" :model="queryParams" :inline="true">
            <el-form-item label="批次号" prop="batchCode">
              <el-input v-model="queryParams.batchCode" placeholder="请输入批次号" clearable @keyup.enter="handleQuery" />
            </el-form-item>
            <el-form-item label="产品型号" prop="prodModel">
              <el-input v-model="queryParams.prodModel" placeholder="请输入产品型号" clearable @keyup.enter="handleQuery" />
            </el-form-item>
            <div style="display: inline" v-if="showMore">
              <el-form-item label="用户编号" prop="userId">
                <el-input v-model="queryParams.userId" placeholder="请输入用户编号" clearable @keyup.enter="handleQuery" />
              </el-form-item>
              <el-form-item label="设备号" prop="deviceCode">
                <el-input v-model="queryParams.deviceCode" placeholder="请输入设备号" clearable @keyup.enter="handleQuery" />
              </el-form-item>
              <el-form-item label="数量" prop="num">
                <el-input v-model="queryParams.num" placeholder="请输入数量" clearable @keyup.enter="handleQuery" />
              </el-form-item>
            </div>

            <el-form-item>
              <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
              <el-button icon="Refresh" @click="resetQuery">重置</el-button>
              <el-button v-if="!showMore" type="text" @click="showMore = !showMore">展开</el-button>
              <el-button v-if="showMore" type="text" @click="showMore = !showMore">收起</el-button>
            </el-form-item>
          </el-form>
        </el-card>
      </div>
    </transition>

    <el-card shadow="never">
      <template #header>
        <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
            <el-button type="primary" plain icon="Plus" @click="handleAdd" v-hasPermi="['qms:batch:add']">新增</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="success" plain icon="Edit" :disabled="single" @click="handleUpdate()" v-hasPermi="['qms:batch:edit']">修改</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="danger" plain icon="Delete" :disabled="multiple" @click="handleDelete()" v-hasPermi="['qms:batch:remove']">删除</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="warning" plain icon="Download" @click="handleExport" v-hasPermi="['qms:batch:export']">导出</el-button>
          </el-col>
          <right-toolbar v-model:showSearch="showSearch" :columns="columns" @queryTable="getList"></right-toolbar>
        </el-row>
      </template>

      <el-table
        v-loading="loading"
        :data="batchList"
        @selection-change="handleSelectionChange"
        stripe
        highlight-current-row
      >
        <el-table-column type="selection" width="55" align="center" />
        <el-table-column label="ID" align="center" prop="id" v-if="columns[0].visible"/>
        <el-table-column label="批次号" align="center" prop="batchCode" v-if="columns[1].visible" />
        <el-table-column label="产品型号" align="center" prop="prodModel" v-if="columns[2].visible" />
        <el-table-column label="用户编号" align="center" prop="userId" v-if="columns[3].visible" />
        <el-table-column label="设备号" align="center" prop="deviceCode" v-if="columns[4].visible" />
        <el-table-column label="数量" align="center" prop="num" v-if="columns[5].visible" />
        <el-table-column label="备注" align="center" prop="remark" v-if="columns[6].visible" />
        <el-table-column label="创建时间" align="center" prop="createTime" v-if="columns[7].visible" />
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-tooltip content="明细" placement="top">
              <el-button link type="primary" icon="Document" @click="handleDetail(scope.row)"></el-button>
            </el-tooltip>
            <el-tooltip content="修改" placement="top">
              <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)" v-hasPermi="['qms:batch:edit']"></el-button>
            </el-tooltip>
            <el-tooltip content="删除" placement="top">
              <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)" v-hasPermi="['qms:batch:remove']"></el-button>
            </el-tooltip>
          </template>
        </el-table-column>
      </el-table>

      <pagination v-show="total > 0" :total="total" v-model:page="queryParams.pageNum" v-model:limit="queryParams.pageSize" @pagination="getList" />
    </el-card>
    <!-- 添加或修改批次管理对话框 -->
    <el-dialog :title="dialog.title" v-model="dialog.visible" width="500px" append-to-body>
      <el-form ref="batchFormRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="批次号" prop="batchCode">
          <el-input v-model="form.batchCode" placeholder="请输入批次号" />
        </el-form-item>
        <el-form-item label="产品型号" prop="prodModel">
          <el-input v-model="form.prodModel" placeholder="请输入产品型号" />
        </el-form-item>
        <el-form-item label="用户编号" prop="userId">
          <el-input v-model="form.userId" placeholder="请输入用户编号" />
        </el-form-item>
        <el-form-item label="设备号" prop="deviceCode">
          <el-input v-model="form.deviceCode" placeholder="请输入设备号" />
        </el-form-item>
        <el-form-item label="数量" prop="num">
          <el-input v-model="form.num" placeholder="请输入数量" />
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入备注" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button :loading="buttonLoading" type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="Batch" lang="ts">
import { listBatch, getBatch, delBatch, addBatch, updateBatch } from '@/api/qms/batch';
import { BatchVO, BatchQuery, BatchForm } from '@/api/qms/batch/types';

const { proxy } = getCurrentInstance() as ComponentInternalInstance;

const batchList = ref<BatchVO[]>([]);
const buttonLoading = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref<Array<string | number>>([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const showMore = ref(false);
const queryFormRef = ref<ElFormInstance>();
const batchFormRef = ref<ElFormInstance>();

const dialog = reactive<DialogOption>({
  visible: false,
  title: ''
});

const initFormData: BatchForm = {
  id: undefined,
  batchCode: undefined,
  prodModel: undefined,
  userId: undefined,
  deviceCode: undefined,
  num: undefined,
  remark: undefined,
  createTime: undefined, // 添加 createTime 字段
}
const data = reactive<PageData<BatchForm, BatchQuery>>({
  form: {...initFormData},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    batchCode: undefined,
    prodModel: undefined,
    userId: undefined,
    deviceCode: undefined,
    num: undefined,
    params: {
    }
  },
  rules: {
    id: [
      { required: true, message: "不能为空", trigger: "blur" }
    ],
    batchCode: [
      { required: true, message: "批次号不能为空", trigger: "blur" }
    ],
    prodModel: [
      { required: true, message: "产品型号不能为空", trigger: "blur" }
    ],
    userId: [
      { required: true, message: "用户编号不能为空", trigger: "blur" }
    ],
    deviceCode: [
      { required: true, message: "设备号不能为空", trigger: "blur" }
    ],
    num: [
      { required: true, message: "数量不能为空", trigger: "blur" }
    ],
  }
});

const { queryParams, form, rules } = toRefs(data);

// 添加 columns 数组
const columns = ref<FieldOption[]>([
  { key: 0, label: 'ID', align: 'center', visible: false },
  { key: 1, label: '批次号', align: 'center', visible: true },
  { key: 2, label: '产品型号', align: 'center', visible: true },
  { key: 3, label: '用户编号', align: 'center', visible: true },
  { key: 4, label: '设备号', align: 'center', visible: true },
  { key: 5, label: '数量', align: 'center', visible: true },
  { key: 6, label: '备注', align: 'center', visible: true },
  { key: 7, label: '创建时间', align: 'center', visible: true },
]);

/** 查询批次管理列表 */
const getList = async () => {
  loading.value = true;
  const res = await listBatch(queryParams.value);
  batchList.value = res.rows;
  total.value = res.total;
  loading.value = false;
}

/** 取消按钮 */
const cancel = () => {
  reset();
  dialog.visible = false;
}

/** 表单重置 */
const reset = () => {
  form.value = {...initFormData};
  batchFormRef.value?.resetFields();
}

/** 搜索按钮操作 */
const handleQuery = () => {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
const resetQuery = () => {
  queryFormRef.value?.resetFields();
  handleQuery();
}

/** 多选框选中数据 */
const handleSelectionChange = (selection: BatchVO[]) => {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
const handleAdd = () => {
  reset();
  dialog.visible = true;
  dialog.title = "添加批次管理";
}

/** 修改按钮操作 */
const handleUpdate = async (row?: BatchVO) => {
  reset();
  const _id = row?.id || ids.value[0]
  const res = await getBatch(_id);
  Object.assign(form.value, res.data);
  dialog.visible = true;
  dialog.title = "修改批次管理";
}

/** 提交按钮 */
const submitForm = () => {
  batchFormRef.value?.validate(async (valid: boolean) => {
    if (valid) {
      buttonLoading.value = true;
      if (form.value.id) {
        await updateBatch(form.value).finally(() =>  buttonLoading.value = false);
      } else {
        await addBatch(form.value).finally(() =>  buttonLoading.value = false);
      }
      proxy?.$modal.msgSuccess("操作成功");
      dialog.visible = false;
      await getList();
    }
  });
}

/** 删除按钮操作 */
const handleDelete = async (row?: BatchVO) => {
  const _ids = row?.id || ids.value;
  await proxy?.$modal.confirm('是否确认删除批次管理编号为"' + _ids + '"的数据项？').finally(() => loading.value = false);
  await delBatch(_ids);
  proxy?.$modal.msgSuccess("删除成功");
  await getList();
}

/** 导出按钮操作 */
const handleExport = () => {
  proxy?.download('qms/batch/export', {
    ...queryParams.value
  }, `batch_${new Date().getTime()}.xlsx`)
}

const handleDetail = (batch) => {
  proxy.$router.push({ path: 'sensorResult', query: {batchCode: batch.batchCode} });
}

onMounted(() => {
  getList();
});
</script>
